@@ -2,6 +2,6 @@ correlation <- function(object, ...) UseMethod("correlation")
 
 correlation.wsrf <- function(object, ...) {
 
-    object$model$estimation["correlation"]
+  object[[.CORRELATION_IDX]]
 
 }
\ No newline at end of file
