@@ -52,7 +52,11 @@ static inline void check_interrupt_impl(void* /*dummy*/) {
     R_CheckUserInterrupt();
 }
 
-inline bool check_interrupt() {
+inline bool check_interrupt()
+/*
+ * Can only be used in top level thread.
+ */
+{
     return (R_ToplevelExec(check_interrupt_impl, NULL) == FALSE);
 }
 
@@ -109,6 +113,18 @@ const string VAR_TYPES            = "vartypes";
 const string VAL_NAMES            = "valnames";
 
 // message
-const string INTERRUPT_MSG = "The random forest model building is interrupted.";
+const string MODEL_INTERRUPT_MSG = "The random forest model building is interrupted.";
+const string PRED_INTERRUPT_MSG  = "Prediction is interrupted.";
+
+const string INER_ERR_SPLIT_MSG         = "Internal error: TrainingSet::SplitByPositon.";
+const string INER_ERR_EMPTY_NODE_MSG    = "Internal error: Empty node.";
+const string INER_ERR_NON_LEAF_NODE_MSG = "Internal error: Internal node has no class label distributions.";
+
+const string EMPTY_DATASET_MSG        = "Empty dataset.";
+const string UNMATCHED_NUM_OF_VAR_MSG = "The number of variables is less than expected.";
+const string UNEXPECTED_VAR_TYPE_MSG  = ": Unexpected variable type.";
+const string VAR_NOT_FOUND_MSG        = ": Variable not found.";
+const string UNEXPECTED_VALUE_MSG     = ": Unexpected values found.";
+
 
 #endif
